timerelationtools.TimeRelation
==============================

.. abjad-lineage:: abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation

.. autoclass:: abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.is_fully_loaded
   :noindex:

.. autoattribute:: abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.is_fully_unloaded
   :noindex:

.. autoattribute:: abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.storage_format
   :noindex:

.. autoattribute:: abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.template
   :noindex:

Methods
-------

.. automethod:: abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.new
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.__call__
   :noindex:

.. automethod:: abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.__eq__
   :noindex:

.. automethod:: abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.__ge__
   :noindex:

.. automethod:: abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.__gt__
   :noindex:

.. automethod:: abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.__le__
   :noindex:

.. automethod:: abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.__lt__
   :noindex:

.. automethod:: abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.__ne__
   :noindex:

.. automethod:: abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.__repr__
   :noindex:
